using System;
using System.Runtime.InteropServices;
using System.Security.Permissions;
using Microsoft.SharePoint;

namespace WingtipToysColumnsContentTypes.Features.Site_ColumnsContentTypes
{
    /// <summary>
    /// This class handles events raised during feature activation, deactivation, installation, uninstallation, and upgrade.
    /// </summary>
    /// <remarks>
    /// The GUID attached to this class may be used during packaging and should not be modified.
    /// </remarks>

    [Guid("1e0fefda-6a7f-423e-b23b-b891588a70be")]
    public class Site_ColumnsContentTypesEventReceiver : SPFeatureReceiver
    {

public override void FeatureActivated(SPFeatureReceiverProperties properties)
{
    using (SPSite currentSite = properties.Feature.Parent as SPSite)
    {
        using (SPWeb currentWeb = currentSite.OpenWeb())
        {
            SPFieldCollection siteColumns = currentWeb.Fields;
            currentWeb.AllowUnsafeUpdates = true;

            if (!siteColumns.ContainsField("ToysPrice2"))
            {
                SPFieldCurrency toysPrice = siteColumns.CreateNewField("Currency", "ToysPrice2") as SPFieldCurrency;
                toysPrice.StaticName = "ToysPrice2";
                toysPrice.Title = "Price2";
                toysPrice.Group = "WingtipToys Columns";
                toysPrice.Required = true;
                toysPrice.DisplayFormat = SPNumberFormatTypes.TwoDecimals;
                currentWeb.Fields.Add(toysPrice);
            }

            if (!siteColumns.ContainsField("AgeGroup2"))
            {
                SPFieldChoice ageGroup = siteColumns.CreateNewField("Choice", "AgeGroup2") as SPFieldChoice;
                ageGroup.StaticName = "AgeGroup2";
                ageGroup.Title = "Age Group2";
                ageGroup.Group = "WingtipToys Columns";
                ageGroup.Required = true;
                ageGroup.Choices.Add("0-1");
                ageGroup.Choices.Add("1-3");
                ageGroup.Choices.Add("3-6");
                ageGroup.Choices.Add("6-9");
                ageGroup.Choices.Add("9-12");
                ageGroup.Choices.Add("12+");
                currentWeb.Fields.Add(ageGroup);
            }

            SPContentTypeCollection contentTypes = currentWeb.ContentTypes;
            if (contentTypes["Toys2"] == null)
            {
                SPContentType toys = new SPContentType(contentTypes[SPBuiltInContentTypeId.Item], contentTypes, "Toys2");
                toys.Group = "WingtipToys Content Types";
                toys.Description = "Content type used to store information about toys";

                SPField toysPrice = currentWeb.Fields.GetFieldByInternalName("ToysPrice2");
                SPField ageGroup = currentWeb.Fields.GetFieldByInternalName("AgeGroup2");
                SPFieldLink toysPriceLink = new SPFieldLink(toysPrice);
                SPFieldLink ageGroupLink = new SPFieldLink(ageGroup);
                toys.FieldLinks.Add(toysPriceLink);
                toys.FieldLinks.Add(ageGroupLink);

                contentTypes.Add(toys);
            }
            currentWeb.AllowUnsafeUpdates = false;
        }
    }
}


        // Uncomment the method below to handle the event raised before a feature is deactivated.

        //public override void FeatureDeactivating(SPFeatureReceiverProperties properties)
        //{
        //}


        // Uncomment the method below to handle the event raised after a feature has been installed.

        //public override void FeatureInstalled(SPFeatureReceiverProperties properties)
        //{
        //}


        // Uncomment the method below to handle the event raised before a feature is uninstalled.

        //public override void FeatureUninstalling(SPFeatureReceiverProperties properties)
        //{
        //}

        // Uncomment the method below to handle the event raised when a feature is upgrading.

        //public override void FeatureUpgrading(SPFeatureReceiverProperties properties, string upgradeActionName, System.Collections.Generic.IDictionary<string, string> parameters)
        //{
        //}
    }
}
