﻿using System;
using System.Web.UI;
using Microsoft.SharePoint;
using Microsoft.Office.RecordsManagement.RecordsRepository;


namespace WingtipToysContentOrganizer.CORulesWebPart
{
    public partial class CORulesWebPartUserControl : UserControl
    {
 
        /// <summary>
        /// Create the Spreadsheet Content Organizer Rule
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void BtnNewRuleClick(object sender, EventArgs e)
        {
            ErrorMessage.Text = String.Empty;

            try
            {
                SPSite currentSite = SPContext.Current.Site;
                SPWeb currentWeb = currentSite.OpenWeb();
                EcmDocumentRoutingWeb contentOrganizerWeb = new EcmDocumentRoutingWeb(currentWeb);

                EcmDocumentRouterRule newRule = new EcmDocumentRouterRule(currentWeb);
                newRule.Name = "Spreadsheets";
                newRule.Priority = "5";

                SPContentType documentContentType = currentWeb.ContentTypes["Document"];
                newRule.ContentTypeString = documentContentType.Name;

                SPField documentTypeField = currentWeb.Fields.GetField("Document Type");
                string ruleOperator = "IsEqual";
                string ruleValue = "Spreadsheet";
                string conditionString = String.Format(@"<Condition Column=""{0}|{1}|{2}"" Operator=""{3}"" Value=""{4}"" />",
                    documentTypeField.Id, documentTypeField.InternalName, documentTypeField.Title, ruleOperator, ruleValue);
                string conditionsXml = String.Format("<Conditions>{0}</Conditions>", conditionString);

                newRule.ConditionsString = conditionsXml;

                SPList spreadSheetLibrary = currentWeb.GetList("Spreadsheets");
                newRule.TargetPath = spreadSheetLibrary.RootFolder.ServerRelativeUrl;

                newRule.Enabled = true;

                contentOrganizerWeb.RoutingRuleCollection.Add(newRule);


            }
            catch (Exception ex)
            {
                ErrorMessage.Text = "An error occurred while trying to create a Content Organizer Rule. " + ex.Message;
            }

        }

    }
}
