using System;
using System.Runtime.InteropServices;
using System.Security.Permissions;
using Microsoft.SharePoint;
using System.Collections.Specialized;

namespace WingTipToysSolution.Features.Web_ContactsList
{
    /// <summary>
    /// This class handles events raised during feature activation, deactivation, installation, uninstallation, and upgrade.
    /// </summary>
    /// <remarks>
    /// The GUID attached to this class may be used during packaging and should not be modified.
    /// </remarks>

    [Guid("05a2eb8a-16e6-4cae-9cb1-4a181c94fd1e")]
    public class Web_ContactsListEventReceiver : SPFeatureReceiver
    {
        string _viewName = "Project Contacts";

        public override void FeatureActivated(SPFeatureReceiverProperties properties)
        {
            SPWeb web = properties.Feature.Parent as SPWeb;
            SPList contactsList = web.GetList("/Lists/WingTipContacts");
            contactsList.OnQuickLaunch = true;

            SPViewCollection listViews = contactsList.Views;
            StringCollection viewFields = new StringCollection();
            viewFields.Add("FirstName");
            viewFields.Add("Title");
            viewFields.Add("Company");
            viewFields.Add("Email");
            viewFields.Add("CellPhone");

            listViews.Add(_viewName, viewFields, string.Empty, 30, true, true);
            contactsList.Update();
        }


        public override void FeatureDeactivating(SPFeatureReceiverProperties properties)
        {
            SPWeb web = properties.Feature.Parent as SPWeb;
            SPList contactsList = web.GetList("/Lists/WingTipContacts");
            contactsList.OnQuickLaunch = false;

            SPView listView = contactsList.Views[_viewName];
            contactsList.Views.Delete(listView.ID);
            contactsList.Update();
        }


        public override void FeatureUpgrading(SPFeatureReceiverProperties properties, 
            string upgradeActionName, 
            System.Collections.Generic.IDictionary<string, string> parameters)
        {
            // perform common initialization for all custom upgrade actions
            SPWeb web= properties.Feature.Parent as SPWeb;
            
            if (web != null) 
            {
                SPList contactsList = web.GetList("/Lists/WingTipContacts");
                            
                // determine which custom upgrade action is executing
                switch (upgradeActionName) 
                {
                    case "UpdateContactsListTitle":
                    
                        //*** begin code for UpdateContactsListTitle upgrade action
                        string newListTitle = parameters["NewListTitle"];
                        contactsList.Title = newListTitle;
                        contactsList.Update();
                        //*** end for UpdateSiteTitle upgrade action
                    
                        break;
                    default:
                        // unexpected feature upgrade action
                        break;
                }
            }
        }

        
        // Uncomment the method below to handle the event raised after a feature has been installed.
        //public override void FeatureInstalled(SPFeatureReceiverProperties properties)
        //{
        //}


        // Uncomment the method below to handle the event raised before a feature is uninstalled.
        //public override void FeatureUninstalling(SPFeatureReceiverProperties properties)
        //{
        //}

    }
}
